# -*- coding: utf-8 -*-
#
# Copyright (C) 2020 CERN
# Copyright (C) 2020 Cottage Labs LLP.
#
# invenio-swh is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Version information for invenio-swh.

This file is imported by ``invenio_swh.__init__``,
and parsed by ``setup.py``.
"""

__version__ = '0.1.dev2'
